@@ -9,49 +9,47 @@ This is a section of usefulpy. See usefulpy.__init__ and usefulpy license
 file
 
 RELEASE NOTES:
-1
- 1.1
-  Version 1.1.1
+0
+ 0.0
+  Version 0.0.0
    Simple math importations with some changes and additions
-  Version 1.1.2
+  Version 0.0.1
    Changed some variable names and importations. More comments.
-2
- 2.1
-  Version 2.1.1
+1
+ 1.0
+  Version 1.0.0
    Reworked a lot of little details to allow for use with complex numbers
    throughout.
-  Version 2.1.2
+  Version 1.0.1
    Several new functions.
-  Version 2.1.3
+  Version 1.0.2
    Bug fixes
- 2.2
-  Version 2.2.1
+ 1.1
+  Version 1.1.0
    Some new functions and changing some internal workings
-  Version 2.2.2
+  Version 1.1.1
    Bug fixes (again)
-3
- 3.1
-  Version 3.1.1
+2
+ 2.0
+  Version 2.0.0
      ——Wednesday, the thirteenth day of the firstmonth Janurary, 2021——
    Rewrote on another document, cleaning up, improving, and adding functions
    throughout
-  Version 3.2.2
+  Version 2.0.1
    Small bugfixes
- 3.2
-  Version 3.2.1
+ 2.1
+  Version 2.1.0
    Mathfunc improvements/ trigfunc stuff, decorators
-  Version 3.2.2
+  Version 2.1.1
    Mathfunc bugfixes
-  Version 3.2.3
+  Version 2.1.2
    More mathfunc and such bugfixes
-  Version 3.2.4
+  Version 2.1.3
    Clean up of code
 '''
 
-##UPDATED TO: Usefulpy 1.2.1
-
 ### DUNDERS ###
-__version__='3.1.1'
+__version__='2.1.3'
 __author__ = 'Austin Garcia'
 __package__='usefulpy.mathematics'
 
@@ -75,7 +73,7 @@ from math import lgamma, modf, nextafter, perm, prod, remainder, trunc, ulp
 
 ### CONVERSIONS ###
 ##TODO: Add more values to conversions
-{'rad':
+conversions = {'rad':
   {'type': 'angle',
    'value': 'tau'
   },
@@ -1222,7 +1220,7 @@ recources to x.__asec__ if sec cannot be found'''
     else:
         try:
             try: return x.__asec__()
-            except: ZeroDivisionError: zde = True
+            except ZeroDivisionError: zde = True
         except:pass
     if zde:
         raise ValueError ('math domain error')
@@ -1242,7 +1240,7 @@ recources to x.__asech__ if sech cannot be found'''
     else:
         try:
             try: return x.__asech__()
-            except: ZeroDivisionError: zde = True
+            except ZeroDivisionError: zde = True
         except:pass
     if zde:
         raise ValueError ('math domain error')
@@ -1262,7 +1260,7 @@ recources to x.__acsc__ if csc cannot be found'''
     else:
         try:
             try: return x.__acsc__()
-            except: ZeroDivisionError: zde = True
+            except ZeroDivisionError: zde = True
         except:pass
     if zde:
         raise ValueError ('math domain error')
@@ -1282,7 +1280,7 @@ recources to x.__acsch__ if csch cannot be found'''
     else:
         try:
             try: return x.__acsch__()
-            except: ZeroDivisionError: zde = True
+            except ZeroDivisionError: zde = True
         except:pass
     if zde:
         raise ValueError ('math domain error')
@@ -1302,8 +1300,8 @@ recources to x.__acot__ if cot cannot be found'''
     else:
         try:
             try: return x.__acot__()
-            except: ZeroDivisionError: zde = True
-        except:pass
+            except ZeroDivisionError: zde = True
+        except: pass
     if zde:
         raise ValueError ('math domain error')
     raise TypeError('acot cannot be found of a type %s' % (type(x)))
@@ -1322,7 +1320,7 @@ recources to x.__acoth__ if coth cannot be found'''
     else:
         try:
             try: return x.__acoth__()
-            except: ZeroDivisionError: zde = True
+            except ZeroDivisionError: zde = True
         except:pass
     if zde:
         raise ValueError ('math domain error')
@@ -1452,9 +1450,6 @@ recources to θ.__sech__ if sech cannot be found'''
 def csc(θ):
     '''Return the cosecant of θ,
 recources to θ.__csc__ if csc cannot be found'''
-    if setting is None: setting = _angle
-    θ = (_validation.trynumber(convert(θ, setting, 'rad')))
-    
     if _validation.is_float(θ):
         try: return _math.sin(1/θ)
         except ZeroDivisionError: pass
